.. _reference:


API reference
=============

.. currentmodule:: udlai


Feature API
-----------

.. autofunction:: attributes

.. autofunction:: attribute_detail

.. autofunction:: features

.. autofunction:: aggregates